--[[
 Adibags - Ren's Filters: Reputation - groups reputation-based items into an AdiBags group
--]]

local addonName, addon = ...
-- Get reference to AdiBags addon
local AdiBags = LibStub("AceAddon-3.0"):GetAddon("AdiBags")
-- Register this addon with AdiBags
local rep_filter = AdiBags:RegisterFilter("AdiBags_RensFilters_Reputation", 80)

-- Localization variable
local L = addon.L

-- Name that is displayed in list of Filters
rep_filter.uiName = L["name"]
-- Description displayed in configuration detail panel
rep_filter.uiDesc = L["desc"]

-- Checks to see if this item is in a filter and returns the filter's
-- group title if so.
function rep_filter:Filter(item)
  if self.db.profile.enable_consumables and addon.rep_consumable[item.itemId] then
    return L["group_title"]
  elseif self.db.profile.enable_quest_items and addon.rep_quest[item.itemId] then
    return L["group_title"]
  elseif self.db.profile.enable_contracts and addon.rep_contracts[item.itemId] then
    return L["group_title"]
  elseif self.db.profile.enable_guild_banners and addon.rep_banners[item.itemId] then
    return L["group_title"]
  elseif self.db.profile.enable_tabards and addon.rep_tabards[item.itemId] then
    return L["group_title"]
  end
end

-- Initializes this addon; only called when WoW is started
function rep_filter:OnInitialize()
  self.db = AdiBags.db:RegisterNamespace("AdiBags_RensFilters_Reputation", {
    profile = {
       enable_consumables = true,
       enable_quest_items = true,
       enable_contracts = true,
       enable_guild_banners = true,
       enable_tabards = true
    }
  })
  AdiBags:Print("Adibags - Ren's Filters: Reputation loaded")
end

-- Returns options for AdiBags to display, if any (there are no options for this addon)
function rep_filter:GetOptions()
  return {
    rep_grouping = {
      name = L["categories"],
      type = 'group',
      inline = true,
      order = 50,
      args = {
        enable_consumables = {
          name = L["name1"],
          desc = L["desc1"],
          type = 'toggle',
          order = 10,
        },
        enable_quest_items = {
          name = L["name2"],
          desc = L["desc2"],
          type = 'toggle',
          order = 20,
        },
        enable_contracts = {
          name = L["name3"],
          desc = L["desc3"],
          type = 'toggle',
          order = 30,
        },
        enable_guild_banners = {
          name = L["name4"],
          desc = L["desc4"],
          type = 'toggle',
          order = 40,
        },
        enable_tabards = {
          name = L["name5"],
          desc = L["desc5"],
          type = 'toggle',
          order = 50,
        },
      }
    },
  },
  -- Notifies AdiBags to update itself for changed options
  AdiBags:GetOptionHandler(self, false, function()
    return self:Update()
  end)
end

-- Notifies AdiBags that it needs to update itself
function rep_filter:Update()
  self:SendMessage("AdiBags_FiltersChanged")
end

-- Notifies AdiBags that this addon is enabled
function rep_filter:OnEnable()
  AdiBags:UpdateFilters()
end

-- Notifies AdiBags that this addon is disabled
function rep_filter:OnDisable()
  AdiBags:UpdateFilters()
end
